## pygame_chess_api package
[![Documentation Status](https://readthedocs.org/projects/pygame-chess-api/badge/?version=latest)](https://pygame-chess-api.readthedocs.io/en/latest/?badge=latest)

Welcome to pygame_chess_api!
==================================

The goal of this package is to be able to **easily setup chess games**, with the **game engine and the graphical user interface given**.
Especially to enable you to *quickly build chess AI*.

If you're having issues with the installation, please try to install pygame manually (`pip install pygame`) and then try again to install `pygame_chess_api`.
If it doesn't work, feel free to open an issue

**Please check the Documentation at https://pygame-chess-api.readthedocs.io/ to access to Quickstart, References, etc**